CustomTextField class

Inheritance

Constructors

CustomTextField({Key? key, TextInputType? textInputType, String labelText = '', String? initialValue, bool? enable, bool readOnly = false, bool? obscureText, Widget? prefix, Widget? suffix, String? title, String? hintText, TextEditingController? controller, int? maxLine, int? maxLength, List<TextInputFormatter>? inputFormatters, ValueChanged<String>? onchange, TextInputAction? textInputAction, double height = 45, int maxLines = 1})
Add Max lines
const

Properties

controller TextEditingController?
change required to not required
final
enable bool?
final
hashCode int
The hash code for this object.
no setterinherited
height double
Add label text
final
hintText String?
final
initialValue String?
final
inputFormatters List<TextInputFormatter>?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelText String
final
maxLength int?
final
maxLine int?
final
maxLines int
Add Size box Height
final
obscureText bool?
final
onchange ValueChanged<String>?
final
prefix Widget?
final
readOnly bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffix Widget?
final
textInputAction TextInputAction?
final
textInputType TextInputType?
final
title String?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited