AppThemeData class

Constructors

AppThemeData()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

darkblue Color
getter/setter pair
indigo Color
getter/setter pair
secondary300 Color
getter/setter pair
tealgreen Color
getter/setter pair
tooltipbackground Color
getter/setter pair

Constants

bellIconColor → const Color
bg → const Color
bg2 → const Color
bgNewsletter → const Color
bgShadowColor → const Color
black → const Color
black1 → const String
blackBoldFontColor → const Color
blueBackground → const Color
bold → const String
btnBG2 → const Color
btnBlackBG → const Color
btnRedBG → const Color
btnSmokyBG → const Color
cartBGColor → const Color
checkboxInactiveBGColor → const Color
circleColor → const Color
colours → const Color
danger50 → const Color
danger100 → const Color
danger200 → const Color
danger300 → const Color
danger400 → const Color
danger500 → const Color
danger600 → const Color
disableDotColor → const Color
dropShadowColor → const Color
extraBold → const String
extraLight → const String
footerColor → const Color
graybg → const Color
grayIconColor → const Color
grey50 → const Color
grey100 → const Color
grey200 → const Color
grey300 → const Color
grey400 → const Color
grey500 → const Color
grey600 → const Color
grey700 → const Color
grey800 → const Color
grey900 → const Color
greyMediumFontColor → const Color
greyTextFieldBorderColor → const Color
hintTextColor → const Color
iconColor → const Color
iconColorNew → const Color
info50 → const Color
info100 → const Color
info200 → const Color
info300 → const Color
info400 → const Color
info500 → const Color
info600 → const Color
labelBg → const Color
light → const String
medium → const String
orangeColor → const Color
photoBgColor → const Color
plannerIconColor → const Color
plannerIconColor2 → const Color
priceTextColor → const Color
primary100 → const Color
primary200 → const Color
primary300 → const Color
primary400 → const Color
primary500 → const Color
primary600 → const Color
primaryColor → const Color
purpleBgColor → const Color
rating → const Color
regular → const String
searchBarLightBgColor → const Color
secondary50 → const Color
secondary100 → const Color
secondary200 → const Color
secondary400 → const Color
secondary500 → const Color
secondary600 → const Color
secondaryBGColor → const Color
semiBold → const String
shadowGreyColor → const Color
success50 → const Color
success100 → const Color
success200 → const Color
success300 → const Color
success400 → const Color
success500 → const Color
success600 → const Color
surface → const Color
surfaceDark → const Color
tealcolor → const Color
termColor → const Color
textFontColor → const Color
tfBg → const Color
tfIcon → const Color
tfPlaceholderTextColor → const Color
thin → const String
transparent → const Color
warning50 → const Color
warning100 → const Color
warning200 → const Color
warning300 → const Color
warning400 → const Color
warning500 → const Color
warning600 → const Color
white → const Color